``schwab-py``: A Schwab API Wrapper
========================================

.. image:: https://img.shields.io/discord/720378361880248621.svg?label=&logo=discord&logoColor=ffffff&color=7389D8&labelColor=6A7EC2
  :target: https://discord.gg/BEr6y6Xqyv

.. image:: https://img.shields.io/endpoint.svg?url=https%3A%2F%2Fshieldsio-patreon.vercel.app%2Fapi%3Fusername%3Dalexgolec%26type%3Dpatrons&style=flat
  :target: https://patreon.com/alexgolec

``schwab-api``
--------------

Background
==========

In 2020, Charles Schwab completed its purchase of TDAmeritrade. Prior to this 
purchase, TDAmeritrade operated (in the author's personal opinion) the most 
high-quality, accessible, and cost effective trading API. It offers developers 
access to their TDAmeritrade accounts, trading in equities, ETFs, and options, 
plus a wide range of historical data. 

Since this purchase, Schwab has begun to transition TDAmeritrade customers onto 
their own service. In late 2022, the announced the TDAmeritrade REST API will be 
included in this transition, which will happen over the course of 2023. 


What is ``schwab-api``?
=======================

The author of this repo (Alex Golec) had previous authored ``tda-api``, an 
unofficial python wrapper around the previous TDAmeritrade API. This library is 
currently the most popular method of accessing this API, with a community of 
hundreds of active users on our Discord server. 

While the details of the forthcoming Schwab API have not yet been announced, 
this repository serves as a placeholder for a python wrapper around it. It 
currently has no functionality. Stay tuned for updates as they become available.



**Disclaimer:** *schwab-api is an unofficial API wrapper. It is in no way 
endorsed by or affiliated with TD Ameritrade, Charles Schwab or any associated 
organization. Make sure to read and understand the terms of service of the 
underlying API before using this package. The authors accept no responsibility 
for any damage that might stem from use of this package. See the LICENSE file 
for more details.*
